## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)
library(evprof)

## ----ev_model-----------------------------------------------------------------
evprof::california_ev_model

## -----------------------------------------------------------------------------
california_ev_model$models

## -----------------------------------------------------------------------------
workday_model <- california_ev_model$models$user_profiles[[1]]
workday_model

## -----------------------------------------------------------------------------
worktime_model <- workday_model[2, ]

## -----------------------------------------------------------------------------
worktime_model$connection_models

## -----------------------------------------------------------------------------
worktime_model$energy_models[[1]]

## -----------------------------------------------------------------------------
worktime_model$energy_models[[1]]$energy_models[[1]]

